@@ -1,7 +1,7 @@
 from unittest import TestCase
 import json
 from uuid import uuid4
-from AsteriskCommand.atxfer import Atxfer
+from AsteriskCommandApi.atxfer import Atxfer
 from tests.commands.auxiliar_commands import Auxiliar
 
 
