@@ -1,6 +1,6 @@
 from unittest import TestCase
 from uuid import uuid4
-from AsteriskCommand.clear_idle_call_actors import ClearIdleCallActors
+from AsteriskCommandApi.clear_idle_call_actors import ClearIdleCallActors
 from tests.commands.auxiliar_commands import Auxiliar
 
 
