@@ -1,6 +1,6 @@
 from unittest import TestCase
 from uuid import uuid4
-from AsteriskCommand.queue_remove import QueueRemove
+from AsteriskCommandApi.queue_remove import QueueRemove
 from tests.commands.auxiliar_commands import Auxiliar
 
 
